==> com.liferay.site.cms.site.initializer-1.0.21-sources.jar: META-INF/resources/js/structure_builder/components/StructureBuilder.tsx <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import '../../../css/structure_builder/StructureBuilder.scss';

import React, {useEffect} from 'react';

import {Config, initializeConfig} from '../config';
import CacheContextProvider from '../contexts/CacheContext';
import StateContextProvider, {useSelector} from '../contexts/StateContext';
import selectStructureId from '../selectors/selectStructureId';
import selectStructureStatus from '../selectors/selectStructureStatus';
import {ObjectDefinition, ObjectDefinitions} from '../types/ObjectDefinition';
import buildState from '../utils/buildState';
import Sidebar from './Sidebar';
import StructureBuilderToolbar from './StructureBuilderToolbar';
import Settings from './settings/Settings';

export default function StructureBuilder({
	config,
	state,
}: {
	config: Config;
	state: {
		mainObjectDefinition: ObjectDefinition;
		objectDefinitions: ObjectDefinitions;
	};
}) {
	initializeConfig(config);

	return (
		<StateContextProvider initialState={buildState(state)}>
			<CacheContextProvider
				initialData={{
					'object-definitions': state.objectDefinitions,
				}}
			>
				<div className="d-flex flex-column structure-builder__wrapper">
					<HistoryManager />

					<StructureBuilderToolbar />

					<div className="d-flex flex-grow-1 p-4">
						<Sidebar />

						<Settings />
					</div>
				</div>
			</CacheContextProvider>
		</StateContextProvider>
	);
}

function HistoryManager() {
	const id = useSelector(selectStructureId);
	const status = useSelector(selectStructureStatus);

	useEffect(() => {
		if (status !== 'published' || !id) {
			return;
		}

		const url = new URL(window.location.href);

		if (url.searchParams.has('objectFolderExternalReferenceCode')) {
			url.searchParams.delete('objectFolderExternalReferenceCode');
		}

		url.searchParams.set('objectDefinitionId', String(id));

		history.replaceState(null, document.head.title, url.href);
	}, [id, status]);

	return null;
}

==> com.liferay.site.cms.site.initializer-1.0.25-sources.jar: META-INF/resources/js/structure_builder/components/StructureBuilder.tsx <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

import '../../../css/structure_builder/StructureBuilder.scss';

import React, {useEffect} from 'react';

import {
	ObjectDefinition,
	ObjectDefinitions,
	ObjectRelationship,
} from '../../common/types/ObjectDefinition';
import {Config, initializeConfig} from '../config';
import CacheContextProvider from '../contexts/CacheContext';
import StateContextProvider, {useSelector} from '../contexts/StateContext';
import selectStructureId from '../selectors/selectStructureId';
import selectStructureStatus from '../selectors/selectStructureStatus';
import buildState from '../utils/buildState';
import ShortcutManager from './ShortcutManager';
import Sidebar from './Sidebar';
import StructureBuilderToolbar from './StructureBuilderToolbar';
import Settings from './settings/Settings';

export default function StructureBuilder({
	config,
	state,
}: {
	config: Config;
	state: {
		mainObjectDefinition: ObjectDefinition;
		objectDefinitions: ObjectDefinitions;
		relatedContentObjectRelationships: ObjectRelationship[];
	};
}) {
	initializeConfig(config);

	return (
		<StateContextProvider initialState={buildState(state)}>
			<CacheContextProvider
				initialData={{
					'object-definitions': state.objectDefinitions,
				}}
			>
				<div className="d-flex flex-column structure-builder__wrapper">
					<HistoryManager />

					<ShortcutManager />

					<StructureBuilderToolbar />

					<div className="d-flex flex-grow-1 p-4">
						<Sidebar />

						<Settings />
					</div>
				</div>
			</CacheContextProvider>
		</StateContextProvider>
	);
}

function HistoryManager() {
	const id = useSelector(selectStructureId);
	const status = useSelector(selectStructureStatus);

	useEffect(() => {
		if (status !== 'published' || !id) {
			return;
		}

		const url = new URL(window.location.href);

		if (url.searchParams.has('objectFolderExternalReferenceCode')) {
			url.searchParams.delete('objectFolderExternalReferenceCode');
		}

		url.searchParams.set('objectDefinitionId', String(id));

		history.replaceState(null, document.head.title, url.href);
	}, [id, status]);

	return null;
}
